import type {Props} from './download-wrapper'
const DownloadWrapper = (props: Props) => props.children
export default DownloadWrapper
